@@ -26,18 +26,38 @@ class GremlinAPI(object):
     def __init__(self):
         pass
 
+    @classmethod
+    def _add_query_param(cls, endpoint, param_name, param_value):
+        if endpoint and param_name and param_value:
+            if '/?' in endpoint and not str(endpoint).endswith('?'):
+                endpoint += f'&{param_name}={param_value}'
+            elif '/?' in endpoint and (str(endpoint).endswith('?') or str(endpoint).endswith('&')):
+                endpoint += f'{param_name}={param_value}'
+            elif '/?' not in endpoint:
+                endpoint += f'/?{param_name}={param_value}'
+        return endpoint
+
+    @classmethod
+    def _build_query_string_endpoint(cls, endpoint, params, **kwargs):
+        if not endpoint:
+            error_msg = 'expected endpoint, received nothing'
+            log.fatal(error_msg)
+            raise GremlinParameterError(error_msg)
+        if not params or type(params) != type(list()):
+            error_msg = f'Expected list of params, received {type(params)}'
+            log.fatal(error_msg)
+            raise(error_msg)
+        for param_name in params:
+            endpoint = cls._add_query_param(endpoint, param_name, cls._error_if_not_param(param_name, **kwargs))
+        return endpoint
+
     @classmethod
     def _optional_team_endpoint(cls, endpoint, **kwargs):
         team_id = cls._info_if_not_param('teamId', **kwargs)
         if not team_id and type(config.team_id) is str:
             team_id = config.team_id
         if team_id:
-            if '/?' in endpoint and not str(endpoint).endswith('?'):
-                endpoint += f'&teamId={team_id}'
-            elif '/?' in endpoint and (str(endpoint).endswith('?') or str(endpoint).endswith('&')):
-                endpoint += f'teamId={team_id}'
-            elif '/?' not in endpoint:
-                endpoint += f'/?teamId={team_id}'
+            endpoint = cls._add_query_param(endpoint, 'teamId', team_id)
         return endpoint
 
     @classmethod
@@ -103,4 +123,3 @@ class GremlinAPI(object):
             log.warning(error_msg)
             param = default
         return param
-
